@@ -56,7 +56,12 @@ class MyCobot(MyCobotCommandGenerator):
         super(MyCobot, self).__init__(debug)
         self.calibration_parameters = calibration_parameters
         import serial
-        self._serial_port = serial.Serial(port, baudrate, timeout=timeout)
+        self._serial_port = serial.Serial()
+        self._serial_port.port = port
+        self._serial_port.baudrate = baudrate
+        self._serial_port.timeout = timeout
+        self._serial_port.rts = False
+        self._serial_port.open()
 
     _write = write
     _read = read
@@ -78,9 +83,11 @@ class MyCobot(MyCobotCommandGenerator):
         self._write(self._flatten(real_command))
 
         if has_reply:
-            data = self._read()
+            data = self._read(genre)
             res = self._process_received(data, genre)
             if genre in [
+                ProtocolCode.ROBOT_VERSION,
+                ProtocolCode.GET_ROBOT_ID,
                 ProtocolCode.IS_POWER_ON,
                 ProtocolCode.IS_CONTROLLER_CONNECTED,
                 ProtocolCode.IS_PAUSED,  # TODO have bug: return b''
@@ -95,12 +102,17 @@ class MyCobot(MyCobotCommandGenerator):
                 ProtocolCode.GET_SPEED,
                 ProtocolCode.GET_ENCODER,
                 ProtocolCode.GET_BASIC_INPUT,
-                ProtocolCode.GET_TOF_DISTANCE
+                ProtocolCode.GET_TOF_DISTANCE,
+                ProtocolCode.GET_END_TYPE,
+                ProtocolCode.GET_MOVEMENT_TYPE,
+                ProtocolCode.GET_REFERENCE_FRAME,
+                ProtocolCode.GET_JOINT_MIN_ANGLE,
+                ProtocolCode.GET_JOINT_MAX_ANGLE
             ]:
                 return self._process_single(res)
             elif genre in [ProtocolCode.GET_ANGLES]:
                 return [self._int2angle(angle) for angle in res]
-            elif genre in [ProtocolCode.GET_COORDS]:
+            elif genre in [ProtocolCode.GET_COORDS, ProtocolCode.GET_TOOL_REFERENCE, ProtocolCode.GET_WORLD_REFERENCE]:
                 if res:
                     r = []
                     for idx in range(3):
@@ -110,30 +122,27 @@ class MyCobot(MyCobotCommandGenerator):
                     return r
                 else:
                     return res
-            elif genre in [
-                ProtocolCode.GET_JOINT_MIN_ANGLE,
-                ProtocolCode.GET_JOINT_MAX_ANGLE,
-            ]:
-                return self._int2angle(res[0]) if res else 0
+            elif genre in [ProtocolCode.GET_SERVO_VOLTAGES]:
+                return [self._int2coord(angle) for angle in res]
             else:
                 return res
         return None
 
     def get_radians(self):
-        """Get all angle return a list
+        """Get the radians of all joints
 
         Return:
-            data_list (list[radian...]):
+            list: A list of float radians [radian1, ...]
         """
         angles = self._mesg(ProtocolCode.GET_ANGLES, has_reply=True)
         return [round(angle * (math.pi / 180), 3) for angle in angles]
 
     def send_radians(self, radians, speed):
-        """Send all angles
+        """Send the radians of all joints to robot arm
 
         Args:
-            radians (list): example [0, 0, 0, 0, 0, 0]
-            speed (int): 0 ~ 100
+            radians: a list of radian values( List[float]), length 6
+            speed: (int )0 ~ 100
         """
         calibration_parameters(len6=radians, speed=speed)
         degrees = [self._angle2int(radian * (180 / math.pi))
@@ -141,6 +150,13 @@ class MyCobot(MyCobotCommandGenerator):
         return self._mesg(ProtocolCode.SEND_ANGLES, degrees, speed)
 
     def sync_send_angles(self, degrees, speed, timeout=7):
+        """Send the angle in synchronous state and return when the target point is reached
+            
+        Args:
+            degrees: a list of degree values(List[float]), length 6.
+            speed: (int) 0 ~ 100
+            timeout: default 7s.
+        """
         t = time.time()
         self.send_angles(degrees, speed)
         while time.time() - t < timeout:
@@ -151,6 +167,14 @@ class MyCobot(MyCobotCommandGenerator):
         return self
 
     def sync_send_coords(self, coords, speed, mode, timeout=7):
+        """Send the coord in synchronous state and return when the target point is reached
+            
+        Args:
+            coords: a list of coord values(List[float])
+            speed: (int) 0 ~ 100
+            mode: (int): 0 - angular, 1 - linear
+            timeout: default 7s.
+        """
         t = time.time()
         self.send_coords(coords, speed, mode)
         while time.time() - t < timeout:
@@ -161,9 +185,7 @@ class MyCobot(MyCobotCommandGenerator):
 
     # Basic for raspberry pi.
     def gpio_init(self):
-        """Init GPIO module.
-        Raspberry Pi version need this.
-        """
+        """Init GPIO module, and set BCM mode."""
         import RPi.GPIO as GPIO  # type: ignore
 
         GPIO.setmode(GPIO.BCM)
@@ -171,9 +193,10 @@ class MyCobot(MyCobotCommandGenerator):
 
     def gpio_output(self, pin, v):
         """Set GPIO output value.
+
         Args:
-            pin: port number(int).
-            v: Output value(int), 1 - GPIO.HEIGH, 0 - GPIO.LOW
+            pin: (int)pin number.
+            v: (int) 0 / 1
         """
         self.gpio.setup(pin, self.gpio.OUT)
         self.gpio.output(pin, v)
